%{?python_enable_dependency_generator}

%if 0%{?rhel} && 0%{?rhel} < 8
# Since the Python 3 stack in EPEL is missing too many dependencies,
# we're sticking with Python 2 there for now.
# And Pagure in Fedora 28 and lower is built for Python 2...
%global __python %{__python2}
%global python_pkgversion 2
%global python_version %{python2_version}
%else
# Default to Python 3 when F29+
%global __python %{__python3}
%global python_pkgversion %{python3_pkgversion}
%global python_version %{python3_version}
%endif

# For now, to keep behavior consistent (and matching pagure package)
%global _python_bytecompile_extra 1

Name:               pagure-dist-git
Version:            1.2.1
Release:            1%{?dist}
Summary:            Pagure Git auth backend for Dist-Git setups

License:            GPLv2+
URL:                https://pagure.io/pagure-dist-git
Source0:            https://releases.pagure.org/%{name}/%{name}-%{version}.tar.gz
BuildArch:          noarch

BuildRequires:      python%{python_pkgversion}-devel
BuildRequires:      python%{python_pkgversion}-setuptools

%if 0%{?rhel} && 0%{?rhel} < 8
Requires:           python%{python_pkgversion}-pdc-client
Requires:           pagure >= 5.2
%else
Recommends:         python%{python_pkgversion}-pdc-client
%endif

# This is actually an extension to Pagure itself and can't be built this way
# So we're changing it all up..
Obsoletes:          python-%{name} < 1.2-2
Obsoletes:          python2-%{name} < 1.2-2
Obsoletes:          python3-%{name} < 1.2-2
# However, we'll preserve some backwards compatibility here
Provides:           python%{python_pkgversion}-%{name} = %{version}-%{release}

%description
This project hosts the logic to generate gitolite's configuration file for
Dist-Git, which has a different access model than regular Pagure Git systems.


%prep
%autosetup


%build
%py_build


%install
%py_install


# Install the different cron job scripts
mkdir -p $RPM_BUILD_ROOT/%{_libexecdir}/pagure-dist-git/
install -p -m 644 scripts/*.py $RPM_BUILD_ROOT/%{_libexecdir}/pagure-dist-git/


%check
# These tests don't currently pass because Pagure doesn't ship its testsuite
exit 0
nosetests-%{python_version} -v


%files
%doc README.rst
%license LICENSE
%{python_sitelib}/dist_git_auth.py*
%{python_sitelib}/pagure_dist_git-%{version}*
%if 0%{?python_pkgversion} != 2
%{python3_sitelib}/__pycache__/dist_git_auth*.pyc
%endif
%{_libexecdir}/pagure-dist-git/


%changelog
* Mon Jan 07 2019 Pierre-Yves Chibon <pingou@pingoured.fr> - 1.2.1-1
- Updated spec file to use the same build mechanism as we use in the pagure
  package
- Fix minimal version of pagure required in the setup.py

* Mon Jan 07 2019 Pierre-Yves Chibon <pingou@pingoured.fr> - 1.2-1
- Adjust the scripts and dist_git_auth module to work with the new internal
  structure of pagure 5.2

* Wed Dec 19 2018 Pierre-Yves Chibon <pingou@pingoured.fr> - 1.1-1
- Include contributors and groups in the people watching bugs in bugzilla
- Make it so SIGs don't require a dash

* Tue Oct 09 2018 Patrick Uiterwijk <puiterwijk@redhat.com> - 1.0-1
- Rewrote to Dynamic auth backend system (new in Pagure 5.0)
- Merged CentOS ACL checks

* Mon Apr 23 2018 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.12-1
- Update to 0.12
- Add namespace to all the url_for() calls
- Make the branch name grey and remove the new PR button for disabled branches
  (querying PDC for that info)
- Add a tag making it obvious when a package is retired on Fedora
- Show disabled branches on main project, ie: *not* forks
- Fix the dist_git_auth backend to the new pagure structure
- Port the different cron scripts to pagure >= 4.0

* Wed Dec 20 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.11.1-1
- Update to 0.11.1
- Ensure releng has always commit ACL
- Do not consider forks when generating the extras JSON files for POC and
  bugzilla

* Tue Nov 28 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.11-1
- Update to 0.11
- Do not take forks into account when retrieving maintainers and watchers (when
  generating the JSON files for bugzilla and owner aliases)
- Do not show the buttons to create new project is pagure is not allowing it
- Make the package description respect new line characters
- Add support for commit flags in the commit view

* Tue Oct 17 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.10-1
- Update to 0.10
- Add a script outputting for each project the people who should be CC'ed
- Add a script outputting for each project the user to put on the -owner alias

* Fri Oct 13 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.9-1
- Update to 0.9
- Show the heads of the branches on the commit list
- Import and customize the user_info template for dist-git

* Fri Oct 06 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.8.1-1
- Update to 0.8.1
- Do not show the banner about disabled PRs on forks

* Wed Oct 04 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.8-2
- Fix installing the different templates in the templates folder

* Wed Oct 04 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.8-1
- Update to 0.8
- Bring Atomic CI results into the pagure experience

* Fri Sep 29 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.7-1
- Update to 0.7
- Fix provenpackager access, they also need branch access
- Add support for the custom username in the SSH URL
- Remove caching when querying PDC so that Gitolite ACLs are not generated
  with stale data (Matt Prahl)
- Warn the committers if PRs are turned off and there is no readme
- Add a small script dumping the main admins of each project in pagure

* Mon Aug 21 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.6-1
- Update to 0.6
- Added a new version of the package sources logo (Ryan Lerch)
- Add a log statement when querying PDC (Ralph Bean)
- Simplify the gitolite rules for forks and add tests for them
- Make the project flake8 valid
- Slightly change text to make it less confusing, per mattdm +1 (Paul W.
  Frields)
- Add support for the provenpackager group in pagure-dist-git
- Adjust the logic to group the users and groups in a single line
- Some package do not allow provenpackager access
- Simplify the index_auth template so it renders faster

* Tue Aug 08 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.5-1
- Update to 0.5
- Drop the delete button when the config is off in repo_info.html
- Add a customized pagure-logo for dist-git
- Add a customized index page to be displayed when the users are logged out
- Drop the + access for the groups, it generates an invalid config
- Give RW+C to the forks
- Include the upstream's url next to the project's description on the overview
- Only compile gitolite's config file

* Mon Jul 24 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.4-1
- Update to 0.4
- Adjust the generation of the configuration with the change made to groups
  (requires pagure >= 3.2)
- Ship a custom repo_info template with information specific for dist-git

* Tue Jul 04 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.3-1
- Update to 0.3
- Adjust the spec file to make it support epel as well as Fedora
- Do not reconfigure the logger when one is already configured
- Rework the plugin to reduce the diff it produces

* Fri Jun 30 2017 Pierre-Yves Chibon <pingou@pingoured.fr> - 0.2-1
- Update to 0.2
- Include the missing entry_point in the setup.py

* Fri Jun 30 2017 Ralph Bean <rbean@redhat.com> - 0.1-1
- Initial packaging for Fedora
